import useSWR, { mutate } from 'swr';
import { getAllCharts, getChart } from '@baseline/client-api/chart';
import { Chart } from '@baseline/types/chart';

export const useCharts = () => {
  const { data, error, isLoading, isValidating } = useSWR<Chart[], unknown>(
    `chart/list`,
    () => getAllCharts(),
  );

  return {
    charts: data,
    isLoading,
    error,
    isValidating,
  };
};

export const useChart = (chartId: string) => {
  const { data, error, isLoading, isValidating } = useSWR<Chart, unknown>(
    chartId ? `chart/${chartId}` : null,
    () => getChart(chartId),
  );

  return {
    chart: data,
    isLoading,
    error,
    isValidating,
  };
};

export const onChartCreated = async (chart: Chart) => {
  await Promise.all([
    mutate<Chart[]>(
      `chart/list`,
      (existingCharts) => [...(existingCharts || []), chart],
      {
        revalidate: false,
      },
    ),
    mutate<Chart>(`chart/${chart.chartId}`, chart),
  ]);
};

export const onChartUpdated = async (chart: Chart) => {
  await Promise.all([
    mutate<Chart[]>(
      `chart/list`,
      (existingCharts) =>
        (existingCharts || []).map((chartExisting) =>
          chartExisting.chartId === chart.chartId ? chart : chartExisting,
        ),
      {
        revalidate: false,
      },
    ),
    mutate<Chart>(`chart/${chart.chartId}`, chart),
  ]);
};

export const onChartDeleted = async (chart: Chart) => {
  await Promise.all([
    mutate<Chart[]>(
      `chart/list`,
      (existingCharts) =>
        (existingCharts || []).filter(
          (chartExisting) => chartExisting.chartId !== chart.chartId,
        ),
      {
        revalidate: false,
      },
    ),
  ]);
};
