import { Chart } from '@baseline/types/chart';
import { getDynamodbConnection, queryItems } from '@baselinejs/dynamodb';
import { ServiceObject } from '../../util/service-object';
import { getErrorMessage } from '../../util/error-message';

const dynamoDb = getDynamodbConnection({
  region: `${process.env.API_REGION}`,
});

export const chartService = new ServiceObject<Chart>({
  dynamoDb: dynamoDb,
  objectName: 'Chart',
  table: `${process.env.APP_NAME}-${process.env.NODE_ENV}-chart`,
  primaryKey: 'chartId',
});

export const getChartsByParentChartId = async (
  parentChartId: string,
): Promise<Chart[]> => {
  try {
    return await queryItems<Chart>({
      dynamoDb: chartService.dynamoDb,
      table: chartService.table,
      keyName: 'parentChart',
      keyValue: parentChartId,
      indexName: 'parentChart-index',
    });
  } catch (error) {
    const message = getErrorMessage(error);
    console.error(`Failed to get ${chartService.objectName}: ${message}`);
    throw new Error(message);
  }
};

export const getChartsByMd5 = async (md5: string): Promise<Chart[]> => {
  try {
    return await queryItems<Chart>({
      dynamoDb: chartService.dynamoDb,
      table: chartService.table,
      keyName: 'md5',
      keyValue: md5,
      indexName: 'md5-index',
    });
  } catch (error) {
    const message = getErrorMessage(error);
    console.error(`Failed to get ${chartService.objectName}: ${message}`);
    throw new Error(message);
  }
};

export const getChartsBySha256 = async (sha256: string): Promise<Chart[]> => {
  try {
    return await queryItems<Chart>({
      dynamoDb: chartService.dynamoDb,
      table: chartService.table,
      keyName: 'sha256',
      keyValue: sha256,
      indexName: 'sha256-index',
    });
  } catch (error) {
    const message = getErrorMessage(error);
    console.error(`Failed to get ${chartService.objectName}: ${message}`);
    throw new Error(message);
  }
};
